#
# spec file for package exec-maven-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The automatic requires would be java-headless >= 9, but the
# binaries are java 8 compatible
%define __requires_exclude java-headless
Name:           exec-maven-plugin
Version:        3.5.1
Release:        1.1
Summary:        Exec Maven Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://www.mojohaus.org/exec-maven-plugin/
Source0:        https://repo1.maven.org/maven2/org/codehaus/mojo/exec-maven-plugin/%{version}/exec-maven-plugin-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  java-devel >= 9
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.commons:commons-exec)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:maven-artifact-transfer)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.mojo:mojo-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-jdk14)
Requires:       java-headless >= 1.8
BuildArch:      noarch

%description
A plugin to allow execution of system and Java programs.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n exec-maven-plugin-%{version}

sed -i 's/\r$//' LICENSE.txt
find . -name *.jar -delete

%pom_remove_plugin :animal-sniffer-maven-plugin

#Drop test part. sonatype-aerther not available
%pom_remove_dep :mockito-core
%pom_remove_dep :maven-plugin-testing-harness

rm -rf src/test/

%pom_xpath_set pom:project/pom:properties/pom:mavenVersion 3

%build
%{mvn_build} -f

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt
%dir %{_javadir}/%{name}

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Mon Jul 21 2025 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.5.1
- Changes of 3.5.1
  * Bug Fixes
    + Add ClassLoader support for ASM ClassWriter
  * Maintenance
    + Fix ITs for Maven 4 rc-3
    + Document how to use env vars in commandlineArgs
- Changes of 3.5.0
  * New features and improvements
    + Add toolchain java path to environment variables in ExecMojo
  * Bug Fixes
    + #322, enable to control the exec:java interaction with JVM
    classloader more finely
  * Maintenance
    + Update site descriptor to 2.0.0
    + Toolchains manual improvements
    + Manage version of maven-toolchains-plugin
- Changes of 3.4.1
  * Bug Fixes
    + Environment variable Path should be used as case-insensitive
    + fix: NPE because declared MavenSession field hides field of
    superclass
  * Maintenance
    + Remove redundant spotless configuration
  * Build
    + Use Maven4 enabled with GH Action
    + Use shared release drafter GH Action
- Chages of 3.4.0
  * New features and improvements
    + Allow <includePluginDependencies> to be specified for the
    exec:exec goal
  * Bug Fixes
    + Do not get UPPERCASE env vars
  * Maintenance
    + Remove Log4j 1.2.x from ITs
  * Build
    + Use Maven 3.9.7 and 4.0.0-beta-3
- Changes of 3.3.0
  * New features and improvements
    + Add option to include runtime and provided
- Changes of 3.2.0
  * New features and improvements
    + Enable to exec:java runnables and not only mains with loosely
    coupled injections
    + Try to get rid of legacy API which can break starting with
    java 17
  * Bug Fixes
    + Fix #401 - Maven v4 compatibility
  * Maintenance
    + ITs improvement
    + Fix documentation formatting, add menu items for new examples
    + Execute mexec-137 also on unix family
    + Remove unused test
  * Build
    + Bump release-drafter/release-drafter from 5 to 6
- Changes of 3.1.1
  * New features and improvements
    + Remove unused killAfter options
    + [#391] Cope with Thread::stop being unavailable in JDK 20+
    + Only prefix program output with thread name when running with
    multiple threads
    + [#389] Add option 'blockSystemExit' to 'java' mojo
    + Require Maven 3.6.3+
    + Ensure maven.properties can be forwarded to system properties
    for exec:java
  * Bug Fixes
    + Fix #158 - Fix non ascii character handling
    + [#323] exec arguments missing
  * Maintenance
    + Code cleanups - use newer JDK features
    + Enable spotless for code formatting
    + Require Maven 3.6.3+
    + ITs cleanups
    + Use Resolver Api for dependency resolving
  * Build
    + Workaround for concurrent access to local repository on
    Windows by ITs
    + Use Maven 3.9.4, 3.8.8 in GitHub build
- Changes of 3.1.0
  * New features and improvements
    + Require Maven 3.2.5
    + Support stream inheritance for the forked process, fixes #71
  * Bug Fixes
    + Fix NullPointerException when using plugin dependencies in
    version 1.6.0
    + preload common pool - issue #198
    + fix handling of LongModulePathArgument and LongClassPathArgument
    + Do not drop environment variables that contain '=' in their value,
    or have no value.
    + Empty argument tag should add empty string instead of null
    + Fixes #160, ensure the java classloader is a child first one and
    supports to excludes some gathered classpath element to solve
    manually conflicts
  * Maintenance
    + Get rid of maven-artifact-transfer from dependencies
    + Cleanup project site
    + Cleanup project
    + Fix build badge for current CI system
    + Enforce JAVA_HOME for ITs
    + Drop Invokable interface
    + Remove unused class
    + Remove unused class and profile to build it
    + Remove unused imports
    + Remove unused fields
    + Bump sniffed signatures
    + fix issue with IBM semu 11
    + [DEPS] remove unused logging dependencies.
    + Fixed message: Removed duplicate space
    + Fix spelling in error msg (occured -> occurred)
  * Build
    + Testing with Maven 3.2.5 and 3.8.6
    + use shared gh action from ASF
    + use Temurin JDK
- Removed patch:
  * exec-maven-plugin-ioexception.patch
    + not needed with this version
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Dec 12 2022 Fridrich Strba <fstrba@suse.com>
- Do not require java-headless >= 9, since the jar works just fine
  with java 8
* Tue Oct 25 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * exec-maven-plugin-ioexception.patch
    + allow building with wider range of plexus-utils versions,
    including the 3.5.0 that does not declare IOException as
    thrown in functions where it is actually not thrown.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.0.0
  * Bug Fixes
    + Resolving "target" dir via "${project.build.directory}", so
    to make sure it can be resolved correctly within multi-module
    builds and if another name than "target" has been configured
    [#124]
    + Ensure mojo descriptors are extracted after compilation #123
    + Argument file for modulepath is generated wrongly when paths
    contains spaces #115
    + java.lang.String cannot be cast to
    org.codehaus.mojo.exec.Modulepath #75
  * Enhancement
    + Resolves #152 - Adds option to redirect program output of
    exec:exec to the maven logger. #153
    + Program output can be difficult to trace and may be jumbled
    with Maven logs when running Maven with multiple threads #152
    + Fix type in Property.java #147
    + Correct spelling and remove redundant "small" #142
    + Fix typo #140
    + <timeout> configuration parameter #128
    + Methodhandles #119
    + Introduce Mock Repository Manager #117
    + Improved docs about <environmentVariables/> config of
    exec:exec goal #104
    + Add CodeTriage badge to mojohaus/exec-maven-plugin #96
    + [Enhancement] Support for JPMS module path for exec:java #90
- Removed patch:
  * exec-maven-plugin-1.6.0-Port-to-Maven-3.patch
    + not needed any more with this version
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid trivial name repetition in summary.
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of exec-maven-plugin 1.6.0
